pub struct ConferenceRecordsService { /* private fields */ }Expand description
Implements a client for the Google Meet API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
conference_record_id: &str,
) -> anyhow::Result<()> {
let client = ConferenceRecordsService::builder().build().await?;
let mut list = client.list_participants()
.set_parent(format!("conferenceRecords/{conference_record_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
REST API for services dealing with conference records.
Configuration
To configure ConferenceRecordsService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://meet.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ConferenceRecordsService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ConferenceRecordsService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ConferenceRecordsService
impl ConferenceRecordsService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ConferenceRecordsService.
let client = ConferenceRecordsService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ConferenceRecordsService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ConferenceRecordsService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_conference_record(&self) -> GetConferenceRecord
pub fn get_conference_record(&self) -> GetConferenceRecord
Gets a conference record by conference ID.
Example
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str
) -> Result<()> {
let response = client.get_conference_record()
.set_name(format!("conferenceRecords/{conference_record_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_conference_records(&self) -> ListConferenceRecords
pub fn list_conference_records(&self) -> ListConferenceRecords
Lists the conference records. By default, ordered by start time and in descending order.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService
) -> Result<()> {
let mut list = client.list_conference_records()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_participant(&self) -> GetParticipant
pub fn get_participant(&self) -> GetParticipant
Gets a participant by participant ID.
Example
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, participant_id: &str
) -> Result<()> {
let response = client.get_participant()
.set_name(format!("conferenceRecords/{conference_record_id}/participants/{participant_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_participants(&self) -> ListParticipants
pub fn list_participants(&self) -> ListParticipants
Lists the participants in a conference record. By default, ordered by join
time and in descending order. This API supports fields as standard
parameters like every other API. However, when the fields request
parameter is omitted, this API defaults to 'participants/*, next_page_token'.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str
) -> Result<()> {
let mut list = client.list_participants()
.set_parent(format!("conferenceRecords/{conference_record_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_participant_session(&self) -> GetParticipantSession
pub fn get_participant_session(&self) -> GetParticipantSession
Gets a participant session by participant session ID.
Example
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, participant_id: &str, participant_session_id: &str
) -> Result<()> {
let response = client.get_participant_session()
.set_name(format!("conferenceRecords/{conference_record_id}/participants/{participant_id}/participantSessions/{participant_session_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_participant_sessions(&self) -> ListParticipantSessions
pub fn list_participant_sessions(&self) -> ListParticipantSessions
Lists the participant sessions of a participant in a conference record. By
default, ordered by join time and in descending order. This API supports
fields as standard parameters like every other API. However, when the
fields request parameter is omitted this API defaults to
'participantsessions/*, next_page_token'.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, participant_id: &str
) -> Result<()> {
let mut list = client.list_participant_sessions()
.set_parent(format!("conferenceRecords/{conference_record_id}/participants/{participant_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_recording(&self) -> GetRecording
pub fn get_recording(&self) -> GetRecording
Gets a recording by recording ID.
Example
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, recording_id: &str
) -> Result<()> {
let response = client.get_recording()
.set_name(format!("conferenceRecords/{conference_record_id}/recordings/{recording_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_recordings(&self) -> ListRecordings
pub fn list_recordings(&self) -> ListRecordings
Lists the recording resources from the conference record. By default, ordered by start time and in ascending order.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str
) -> Result<()> {
let mut list = client.list_recordings()
.set_parent(format!("conferenceRecords/{conference_record_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_transcript(&self) -> GetTranscript
pub fn get_transcript(&self) -> GetTranscript
Gets a transcript by transcript ID.
Example
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, transcript_id: &str
) -> Result<()> {
let response = client.get_transcript()
.set_name(format!("conferenceRecords/{conference_record_id}/transcripts/{transcript_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_transcripts(&self) -> ListTranscripts
pub fn list_transcripts(&self) -> ListTranscripts
Lists the set of transcripts from the conference record. By default, ordered by start time and in ascending order.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str
) -> Result<()> {
let mut list = client.list_transcripts()
.set_parent(format!("conferenceRecords/{conference_record_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_transcript_entry(&self) -> GetTranscriptEntry
pub fn get_transcript_entry(&self) -> GetTranscriptEntry
Gets a TranscriptEntry resource by entry ID.
Note: The transcript entries returned by the Google Meet API might not match the transcription found in the Google Docs transcript file. This can occur when the Google Docs transcript file is modified after generation.
Example
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, transcript_id: &str, entry_id: &str
) -> Result<()> {
let response = client.get_transcript_entry()
.set_name(format!("conferenceRecords/{conference_record_id}/transcripts/{transcript_id}/entries/{entry_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_transcript_entries(&self) -> ListTranscriptEntries
pub fn list_transcript_entries(&self) -> ListTranscriptEntries
Lists the structured transcript entries per transcript. By default, ordered by start time and in ascending order.
Note: The transcript entries returned by the Google Meet API might not match the transcription found in the Google Docs transcript file. This can occur when the Google Docs transcript file is modified after generation.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_apps_meet_v2::Result;
async fn sample(
client: &ConferenceRecordsService, conference_record_id: &str, transcript_id: &str
) -> Result<()> {
let mut list = client.list_transcript_entries()
.set_parent(format!("conferenceRecords/{conference_record_id}/transcripts/{transcript_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Trait Implementations
Sourceimpl Clone for ConferenceRecordsService
impl Clone for ConferenceRecordsService
Sourcefn clone(&self) -> ConferenceRecordsService
fn clone(&self) -> ConferenceRecordsService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more